@@ -30,6 +30,10 @@ class Feature(GeoJSON):
                             if geometry else None)
         self["properties"] = properties or {}
 
+    def errors(self):
+        geo = self.get('geometry')
+        return geo.errors() if geo else None
+
 
 class FeatureCollection(GeoJSON):
     """
@@ -46,3 +50,12 @@ class FeatureCollection(GeoJSON):
         """
         super(FeatureCollection, self).__init__(**extra)
         self["features"] = features
+
+    def errors(self):
+        return self.check_list_errors(lambda x: x.errors(), self.features)
+
+    def __getitem__(self, key):
+        try:
+            return self.get("features", ())[key]
+        except (KeyError, TypeError, IndexError):
+            return super(GeoJSON, self).__getitem__(key)
