@@ -140,3 +140,8 @@ class EncodingDecodingTest(unittest.TestCase):
     def test_mapping(self):
         self.assertEquals(to_mapping(geojson.Point([1, 2])),
                           {"coordinates": [1, 2], "type": "Point"})
+
+    def test_GeoJSON(self):
+        self.assertEquals(None, geojson.GeoJSON().__geo_interface__)
+
+        self.assertEquals({"type": "GeoJSON"}, to_mapping(geojson.GeoJSON()))
